import { InjectionToken, Injectable, Inject, NgModule } from '@angular/core';
import { Subject } from 'rxjs';
import { map, filter, take } from 'rxjs/operators';
import { io } from 'socket.io-client';

const SOCKETIO_CONFIG = new InjectionToken('SocketioConfig');

class Socketio {
    constructor({ url, options }) {
        this.subject = new Subject();
        this.socket = io(url, options);
        this.socket.onAny((eventName, ...args) => {
            this.subject.next({ eventName, args });
        });
    }
    get id() { return this.socket.id; }
    ;
    get connected() { return this.socket.connected; }
    ;
    get disconnected() { return this.socket.disconnected; }
    ;
    get io() { return this.socket.io; }
    ;
    get auth() { return this.socket.auth; }
    ;
    ngOnDestroy() {
        this.socket.offAny();
        this.subject.complete();
    }
    connect() {
        this.socket.connect();
        return this;
    }
    disconnect() {
        this.socket.disconnect();
        return this;
    }
    send(...args) {
        this.socket.send(...args);
        return this;
    }
    emit(eventName, ...args) {
        this.socket.emit(eventName, ...args);
        return this;
    }
    on(eventName) {
        const observable = this.subject.asObservable();
        if (!eventName) {
            return observable.pipe(map(({ args }) => (args.length === 1 ? args[0] : args)));
        }
        return observable.pipe(filter(o => o.eventName === eventName), map(({ args }) => (args.length === 1 ? args[0] : args)));
    }
    once(eventName) {
        return this.on(eventName).pipe(take(1));
    }
    compress(compress) {
        this.socket.compress(compress);
        return this;
    }
}
Socketio.decorators = [
    { type: Injectable }
];
Socketio.ctorParameters = () => [
    { type: undefined, decorators: [{ type: Inject, args: [SOCKETIO_CONFIG,] }] }
];

class SocketioModule {
    static forRoot(config = { url: '' }) {
        return {
            ngModule: SocketioModule,
            providers: [
                { provide: SOCKETIO_CONFIG, useValue: config },
                { provide: Socketio, useClass: Socketio },
            ],
        };
    }
}
SocketioModule.decorators = [
    { type: NgModule }
];

/*
 * Public API Surface of ngx-socketio2
 */

/**
 * Generated bundle index. Do not edit.
 */

export { Socketio, SocketioModule, SOCKETIO_CONFIG as ɵa };
//# sourceMappingURL=ngx-socketio2.js.map
